/***************************************************************************
                          defs_urls.h  -  description
                             -------------------
    copyright            : (C) 2008 by Albert santoni
    email                :
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DEFS_URLS_H
#define DEFS_URLS_H

#define MIXXX_WEBSITE_URL       "http://www.mixxx.org"
#define MIXXX_SUPPORT_URL       "http://www.mixxx.org/support.php"
#define MIXXX_FEEDBACK_URL      "https://docs.google.com/forms/d/1Zbx-VgdcSIuTTmy9UalNZhtDypSJdSLvRVZ0MKOuLu4/viewform"
#define MIXXX_TRANSLATION_URL   "https://translations.launchpad.net/mixxx"
#define MIXXX_MANUAL_URL        "http://mixxx.org/manual/1.11"
#define MIXXX_MANUAL_FILENAME   "Mixxx-Manual.pdf"
#define MIXXX_PROMO_URL         "http://promo.mixxx.org/"

#endif
